@@ -1,7 +1,7 @@
 
 
 import os
-from ebs.linuxnode.gui.kivy.background.mixin import BackgroundMixin
+from ebs.linuxnode.gui.kivy.background.mixin import BackgroundGuiMixin
 from .text import FontsGuiMixin
 from .log import LoggingGuiMixin
 from .busy import BusySpinnerGuiMixin
@@ -13,7 +13,7 @@ class BaseIoTNodeGui(NodeIDGuiMixin,
                      BusySpinnerGuiMixin,
                      LoggingGuiMixin,
                      FontsGuiMixin,
-                     BackgroundMixin,
+                     BackgroundGuiMixin,
                      DisplayMixin):
 
     def __init__(self, *args, **kwargs):
@@ -35,3 +35,6 @@ class BaseIoTNodeGui(NodeIDGuiMixin,
     def gui_setup(self):
         super(BaseIoTNodeGui, self).gui_setup()
         return self.gui_root
+
+    def exit(self):
+        self._application.stop()
